;; Generated package description from gnorb.el  -*- no-byte-compile: t -*-
(define-package "gnorb" "1.6.11.0.20230108.110132" "Glue code between Gnus, Org, and BBDB" '((cl-lib "0.5")) :commit "409e4fc2c83f8406f362028dbcc3a1fc21182819" :url "https://elpa.gnu.org/packages/gnorb.html" :authors '(("Eric Abrahamsen" . "eric@ericabrahamsen.net")) :maintainer '("Eric Abrahamsen" . "eric@ericabrahamsen.net") :keywords '("mail" "org" "gnus" "bbdb" "todo" "task"))
